# Goordinates

### Goordinates is a Python package that allows you to easily get latitude and longitude information from a Google Map URL.  
### Usage
```
from Goordinates import Gmap

lat, lng = Gmap.GetCoordinate(map_url)
```